pub struct AnalogCacheEntry {
inner: OnceLock<AnalogSignalCache>,
pub cache_key: AnalogCacheKey,
pub generation: u64,
}Expand description
Wrapper for analog cache with reference counting and lazy initialization.
Used for cache sharing between variables with the same signal+translator combo.
The cache is built asynchronously and set via OnceLock when ready.
Fields
inner: OnceLock<AnalogSignalCache>cache_key: AnalogCacheKeygeneration: u64Implementations
Sourceimpl AnalogCacheEntry
impl AnalogCacheEntry
pub fn new(cache_key: AnalogCacheKey, generation: u64) -> Self
pub fn is_ready(&self) -> bool
pub fn get(&self) -> Option<&AnalogSignalCache>
pub fn set(&self, cache: AnalogSignalCache)